# algorithmia-api-client
APIs for managing actions on the Algorithmia platform

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.1
- Package version: 1.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://algorithmia.com/contact](https://algorithmia.com/contact)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import algorithmia_api_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import algorithmia_api_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import algorithmia_api_client
from algorithmia_api_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = algorithmia_api_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = algorithmia_api_client.DefaultApi(algorithmia_api_client.ApiClient(configuration))
org_name = 'org_name_example' # str | Organization name
username = 'username_example' # str | The user's username

try:
    # Add a user as a member of a given organization
    api_instance.add_organization_member(org_name, username)
except ApiException as e:
    print("Exception when calling DefaultApi->add_organization_member: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.algorithmia.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**add_organization_member**](docs/DefaultApi.md#add_organization_member) | **PUT** /organizations/{orgName}/members/{username} | Add a user as a member of a given organization
*DefaultApi* | [**algorithms_username_algoname_compile_post**](docs/DefaultApi.md#algorithms_username_algoname_compile_post) | **POST** /algorithms/{username}/{algoname}/compile | Compile algorithm
*DefaultApi* | [**commit_log_for_repository**](docs/DefaultApi.md#commit_log_for_repository) | **GET** /algorithms/{username}/{algoname}/log | Gets the list of commits for a repository
*DefaultApi* | [**create_algorithm**](docs/DefaultApi.md#create_algorithm) | **POST** /algorithms/{username} | Create Algorithm
*DefaultApi* | [**create_organization**](docs/DefaultApi.md#create_organization) | **POST** /organizations | Creates an Organization owned by the caller
*DefaultApi* | [**create_user**](docs/DefaultApi.md#create_user) | **POST** /users | Creates an Algorithmia user in the system
*DefaultApi* | [**delete_algorithm**](docs/DefaultApi.md#delete_algorithm) | **DELETE** /algorithms/{username}/{algoname} | Delete Algorithm
*DefaultApi* | [**delete_config_entry**](docs/DefaultApi.md#delete_config_entry) | **DELETE** /config/frontend/{keyname} | Delete a config entry represented by the provided keyname
*DefaultApi* | [**delete_favicon**](docs/DefaultApi.md#delete_favicon) | **DELETE** /config/favicon | Delete favicon for the Algorithmia instance
*DefaultApi* | [**delete_logo**](docs/DefaultApi.md#delete_logo) | **DELETE** /config/logo | Delete logo for the Algorithmia instance
*DefaultApi* | [**delete_organization**](docs/DefaultApi.md#delete_organization) | **DELETE** /organizations/{orgName} | Delete an organization
*DefaultApi* | [**delete_user**](docs/DefaultApi.md#delete_user) | **DELETE** /users/{username} | Delete a user represented by the provided username
*DefaultApi* | [**get_algorithm**](docs/DefaultApi.md#get_algorithm) | **GET** /algorithms/{username}/{algoname} | Get Algorithm
*DefaultApi* | [**get_algorithm_build_by_id**](docs/DefaultApi.md#get_algorithm_build_by_id) | **GET** /algorithms/{username}/{algoname}/builds/{buildid} | Get individual algorithm build by ID
*DefaultApi* | [**get_algorithm_build_logs**](docs/DefaultApi.md#get_algorithm_build_logs) | **GET** /algorithms/{username}/{algoname}/builds/{buildid}/logs | Get Algorithm build logs
*DefaultApi* | [**get_algorithm_builds**](docs/DefaultApi.md#get_algorithm_builds) | **GET** /algorithms/{username}/{algoname}/builds | Get Algorithm builds
*DefaultApi* | [**get_algorithm_hash_version**](docs/DefaultApi.md#get_algorithm_hash_version) | **GET** /algorithms/{username}/{algoname}/versions/{algohash} | Get Algorithm by Hash Version
*DefaultApi* | [**get_algorithm_versions**](docs/DefaultApi.md#get_algorithm_versions) | **GET** /algorithms/{username}/{algoname}/versions | Get Algorithm versions
*DefaultApi* | [**get_config_entry**](docs/DefaultApi.md#get_config_entry) | **GET** /config/frontend/{keyname} | Get a frontend config entry represeted by the provided keyname
*DefaultApi* | [**get_favicon**](docs/DefaultApi.md#get_favicon) | **GET** /config/favicon | Get favicon for the Algorithmia instance
*DefaultApi* | [**get_frontend_config_entries**](docs/DefaultApi.md#get_frontend_config_entries) | **GET** /config/frontend | Lists all frontend configuration values
*DefaultApi* | [**get_logo**](docs/DefaultApi.md#get_logo) | **GET** /config/logo | Get logo for the Algorithmia instance
*DefaultApi* | [**get_organization**](docs/DefaultApi.md#get_organization) | **GET** /organizations/{orgName} | Get an organization represented by the provided orgName
*DefaultApi* | [**get_organizations**](docs/DefaultApi.md#get_organizations) | **GET** /organizations | Lists all organizations
*DefaultApi* | [**get_package_set_builds**](docs/DefaultApi.md#get_package_set_builds) | **GET** /package-sets/{package_set_name}/builds | Name of a package set
*DefaultApi* | [**get_user**](docs/DefaultApi.md#get_user) | **GET** /users/{username} | Get a user represented by the provided username
*DefaultApi* | [**get_users**](docs/DefaultApi.md#get_users) | **GET** /users | Lists all managed users
*DefaultApi* | [**list_entities_for_label**](docs/DefaultApi.md#list_entities_for_label) | **GET** /users/{username}/scm-entities/{label} | List the unique set of entities associated with the token associated to the connection established between the user and the SCM configuration (determined by label)
*DefaultApi* | [**list_members**](docs/DefaultApi.md#list_members) | **GET** /organizations/{orgName}/members | List of members with their roles in a given organization
*DefaultApi* | [**list_scm_connections**](docs/DefaultApi.md#list_scm_connections) | **GET** /users/{username}/scm-connections | List the SCM connections associated with this user
*DefaultApi* | [**list_scm_integrations**](docs/DefaultApi.md#list_scm_integrations) | **GET** /scm-integrations | Get the list of SCM systems that have been configured with this cluster
*DefaultApi* | [**publish_algorithm**](docs/DefaultApi.md#publish_algorithm) | **POST** /algorithms/{username}/{algoname}/versions | Publish Algorithm
*DefaultApi* | [**remove_organization_member**](docs/DefaultApi.md#remove_organization_member) | **DELETE** /organizations/{orgName}/members/{username} | Remove a user from an organization
*DefaultApi* | [**update_algorithm**](docs/DefaultApi.md#update_algorithm) | **PUT** /algorithms/{username}/{algoname} | Update Algorithm
*DefaultApi* | [**update_build_status**](docs/DefaultApi.md#update_build_status) | **PATCH** /package-sets/builds/{build_id}/{image_type} | Update the status of a package set build
*DefaultApi* | [**update_config_entry**](docs/DefaultApi.md#update_config_entry) | **PUT** /config/frontend/{keyname} | Update or insert a config entry represented by the provided keyname
*DefaultApi* | [**update_favicon**](docs/DefaultApi.md#update_favicon) | **POST** /config/favicon | Update favicon for the Algorithmia instance
*DefaultApi* | [**update_logo**](docs/DefaultApi.md#update_logo) | **POST** /config/logo | Update logo for the Algorithmia instance
*DefaultApi* | [**update_package_set**](docs/DefaultApi.md#update_package_set) | **PUT** /package-sets/{package_set_name} | Update a package set
*DefaultApi* | [**update_scm_connection_owner**](docs/DefaultApi.md#update_scm_connection_owner) | **PUT** /users/{username}/scm-connections/{label}/owner | Update the owner of the SCM connection
*DefaultApi* | [**update_user**](docs/DefaultApi.md#update_user) | **PUT** /users/{username} | Update a user represented by the provided username
*DefaultApi* | [**upload_profile_image**](docs/DefaultApi.md#upload_profile_image) | **PUT** /users/{username}/avatar | Upload a profile picture


## Documentation For Models

 - [AlgorithmCallability](docs/AlgorithmCallability.md)
 - [Build](docs/Build.md)
 - [BuildLogs](docs/BuildLogs.md)
 - [BuildVersionInfo](docs/BuildVersionInfo.md)
 - [Commit](docs/Commit.md)
 - [Compilation](docs/Compilation.md)
 - [CreateRequest](docs/CreateRequest.md)
 - [CreateRequestVersionInfo](docs/CreateRequestVersionInfo.md)
 - [Details](docs/Details.md)
 - [Environment](docs/Environment.md)
 - [Error](docs/Error.md)
 - [FrontendConfigurationEntry](docs/FrontendConfigurationEntry.md)
 - [HashResponse](docs/HashResponse.md)
 - [InlineObject](docs/InlineObject.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse401](docs/InlineResponse401.md)
 - [Language](docs/Language.md)
 - [License](docs/License.md)
 - [NetworkAccess](docs/NetworkAccess.md)
 - [Organization](docs/Organization.md)
 - [OrganizationMember](docs/OrganizationMember.md)
 - [PackageSetBuild](docs/PackageSetBuild.md)
 - [PackageSetUpdateRequestBody](docs/PackageSetUpdateRequestBody.md)
 - [PagedBuildsList](docs/PagedBuildsList.md)
 - [PagedResultList](docs/PagedResultList.md)
 - [PagedVersionsList](docs/PagedVersionsList.md)
 - [RepositoryCommitLog](docs/RepositoryCommitLog.md)
 - [ScmConnection](docs/ScmConnection.md)
 - [ScmConnectionOwner](docs/ScmConnectionOwner.md)
 - [ScmConnectionWithOauthUsername](docs/ScmConnectionWithOauthUsername.md)
 - [ScmConnections](docs/ScmConnections.md)
 - [ScmEntities](docs/ScmEntities.md)
 - [ScmIntegration](docs/ScmIntegration.md)
 - [ScmIntegrations](docs/ScmIntegrations.md)
 - [ScmType](docs/ScmType.md)
 - [Settings](docs/Settings.md)
 - [SettingsMandatory](docs/SettingsMandatory.md)
 - [SettingsPublish](docs/SettingsPublish.md)
 - [SourceControlManagementSystem](docs/SourceControlManagementSystem.md)
 - [SourceVisibility](docs/SourceVisibility.md)
 - [StatusUpdateRequest](docs/StatusUpdateRequest.md)
 - [UpdateRequest](docs/UpdateRequest.md)
 - [User](docs/User.md)
 - [VersionInfo](docs/VersionInfo.md)
 - [VersionInfoPublish](docs/VersionInfoPublish.md)
 - [VersionRequest](docs/VersionRequest.md)
 - [VersionResponse](docs/VersionResponse.md)
 - [VersionType](docs/VersionType.md)


## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

support@algorithmia.com


